pub struct BacktestEngineConfig {Show 23 fields
pub environment: Environment,
pub trader_id: TraderId,
pub load_state: bool,
pub save_state: bool,
pub shutdown_on_error: bool,
pub logging: LoggerConfig,
pub instance_id: Option<UUID4>,
pub timeout_connection: Duration,
pub timeout_reconciliation: Duration,
pub timeout_portfolio: Duration,
pub timeout_disconnection: Duration,
pub delay_post_stop: Duration,
pub timeout_shutdown: Duration,
pub cache: Option<CacheConfig>,
pub msgbus: Option<MessageBusConfig>,
pub data_engine: Option<DataEngineConfig>,
pub risk_engine: Option<RiskEngineConfig>,
pub exec_engine: Option<ExecutionEngineConfig>,
pub portfolio: Option<PortfolioConfig>,
pub controller: Option<ImportableControllerConfig>,
pub streaming: Option<StreamingConfig>,
pub bypass_logging: bool,
pub run_analysis: bool,
}Expand description
Configuration for BacktestEngine instances.
Fields
environment: EnvironmentThe kernel environment context.
trader_id: TraderIdThe trader ID for the node.
load_state: boolIf actor and strategy state should be loaded from the database on start.
save_state: boolIf actor and strategy state should be saved to the database on stop.
shutdown_on_error: boolIf the system should request shutdown when an error log is emitted.
Filtered or bypassed error logs still request shutdown.
logging: LoggerConfigThe logging configuration for the kernel.
instance_id: Option<UUID4>The unique instance identifier for the kernel.
timeout_connection: DurationThe timeout for all clients to connect and initialize.
timeout_reconciliation: DurationThe timeout for execution state to reconcile.
timeout_portfolio: DurationThe timeout for portfolio to initialize margins and unrealized pnls.
timeout_disconnection: DurationThe timeout for all engine clients to disconnect.
delay_post_stop: DurationThe delay after stopping the node to await residual events before final shutdown.
timeout_shutdown: DurationThe timeout to await pending tasks cancellation during shutdown.
cache: Option<CacheConfig>The cache configuration.
crate::engine::BacktestEngine always overrides
drop_instruments_on_reset to false on this config so that
successive runs can reuse the same dataset.
msgbus: Option<MessageBusConfig>The message bus configuration.
data_engine: Option<DataEngineConfig>The data engine configuration.
risk_engine: Option<RiskEngineConfig>The risk engine configuration.
exec_engine: Option<ExecutionEngineConfig>The execution engine configuration.
portfolio: Option<PortfolioConfig>The portfolio configuration.
controller: Option<ImportableControllerConfig>The importable controller configuration.
streaming: Option<StreamingConfig>The configuration for streaming to feather files.
bypass_logging: boolIf logging should be bypassed.
run_analysis: boolIf post backtest performance analysis should be run.
Implementations
Sourceimpl BacktestEngineConfig
impl BacktestEngineConfig
Sourcepub fn builder() -> BacktestEngineConfigBuilder
pub fn builder() -> BacktestEngineConfigBuilder
Create an instance of BacktestEngineConfig using the builder syntax