pub struct BacktestResult {Show 17 fields
pub trader_id: String,
pub machine_id: String,
pub instance_id: UUID4,
pub run_config_id: Option<String>,
pub run_id: Option<UUID4>,
pub run_started: Option<UnixNanos>,
pub run_finished: Option<UnixNanos>,
pub backtest_start: Option<UnixNanos>,
pub backtest_end: Option<UnixNanos>,
pub elapsed_time_secs: f64,
pub iterations: usize,
pub total_events: usize,
pub total_orders: usize,
pub total_positions: usize,
pub stats_pnls: AHashMap<String, AHashMap<String, f64>>,
pub stats_returns: AHashMap<String, f64>,
pub stats_general: AHashMap<String, f64>,
}Expand description
Results from a completed backtest run.
Fields
trader_id: Stringmachine_id: Stringinstance_id: UUID4run_config_id: Option<String>run_id: Option<UUID4>run_started: Option<UnixNanos>run_finished: Option<UnixNanos>backtest_start: Option<UnixNanos>backtest_end: Option<UnixNanos>elapsed_time_secs: f64iterations: usizetotal_events: usizetotal_orders: usizetotal_positions: usizestats_pnls: AHashMap<String, AHashMap<String, f64>>stats_returns: AHashMap<String, f64>stats_general: AHashMap<String, f64>Trait Implementations
Sourceimpl Debug for BacktestResult
impl Debug for BacktestResult
Sourceimpl<'py> IntoPyObject<'py> for BacktestResult
impl<'py> IntoPyObject<'py> for BacktestResult
Sourcetype Target = BacktestResult
type Target = BacktestResult
The Python output type
Sourcetype Output = Bound<'py, <BacktestResult as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <BacktestResult as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for BacktestResult
impl PyClass for BacktestResult
Sourceimpl PyClassImpl for BacktestResult
impl PyClassImpl for BacktestResult
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Results from a completed backtest run.
const RAW_DOC: &'static CStr = /// Results from a completed backtest run.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<BacktestResult as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<BacktestResult>
type Layout = <<BacktestResult as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<BacktestResult>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyMethods<BacktestResult> for PyClassImplCollector<BacktestResult>
impl PyMethods<BacktestResult> for PyClassImplCollector<BacktestResult>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for BacktestResult
impl PyTypeInfo for BacktestResult
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0: prefer using
::type_object(py).name() to get the correct runtime valueClass name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0: prefer using
::type_object(py).module() to get the correct runtime valueModule name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for BacktestResult