pub struct BacktestDataConfig { /* private fields */ }Expand description
Represents the data configuration for one specific backtest run.
Implementations
Sourceimpl BacktestDataConfig
impl BacktestDataConfig
pub fn new( data_type: NautilusDataType, catalog_path: String, catalog_fs_protocol: Option<String>, catalog_fs_storage_options: Option<AHashMap<String, String>>, instrument_id: Option<InstrumentId>, instrument_ids: Option<Vec<InstrumentId>>, start_time: Option<UnixNanos>, end_time: Option<UnixNanos>, filter_expr: Option<String>, client_id: Option<ClientId>, metadata: Option<AHashMap<String, String>>, bar_spec: Option<BarSpecification>, bar_types: Option<Vec<String>>, optimize_file_loading: Option<bool>, ) -> Self
pub const fn data_type(&self) -> NautilusDataType
pub fn catalog_path(&self) -> &str
pub fn catalog_fs_protocol(&self) -> Option<&str>
pub fn catalog_fs_storage_options(&self) -> Option<&AHashMap<String, String>>
pub fn instrument_id(&self) -> Option<InstrumentId>
pub fn instrument_ids(&self) -> Option<&[InstrumentId]>
pub fn start_time(&self) -> Option<UnixNanos>
pub fn end_time(&self) -> Option<UnixNanos>
pub fn filter_expr(&self) -> Option<&str>
pub fn client_id(&self) -> Option<ClientId>
pub fn bar_spec(&self) -> Option<BarSpecification>
pub fn bar_types(&self) -> Option<&[String]>
pub fn optimize_file_loading(&self) -> bool
Sourcepub fn query_identifiers(&self) -> Option<Vec<String>>
pub fn query_identifiers(&self) -> Option<Vec<String>>
Constructs identifier strings for catalog queries.
Follows the same logic as Python’s BacktestDataConfig.query:
- For bars: prefer
bar_types, else construct from instrument(s) + bar_spec + “-EXTERNAL” - For other types: use
instrument_idorinstrument_ids
Sourcepub fn get_instrument_ids(&self) -> Result<Vec<InstrumentId>>
pub fn get_instrument_ids(&self) -> Result<Vec<InstrumentId>>
Returns all instrument IDs referenced by this config.
For bar_types, extracts the instrument ID from each bar type string.
Errors
Returns an error if any bar type string cannot be parsed.