BacktestEngineConfig

Struct BacktestEngineConfig 

pub struct BacktestEngineConfig {
Show 21 fields pub environment: Environment, pub trader_id: TraderId, pub load_state: bool, pub save_state: bool, pub logging: LoggerConfig, pub instance_id: Option<UUID4>, pub timeout_connection: Duration, pub timeout_reconciliation: Duration, pub timeout_portfolio: Duration, pub timeout_disconnection: Duration, pub delay_post_stop: Duration, pub timeout_shutdown: Duration, pub cache: Option<CacheConfig>, pub msgbus: Option<MessageBusConfig>, pub data_engine: Option<DataEngineConfig>, pub risk_engine: Option<RiskEngineConfig>, pub exec_engine: Option<ExecutionEngineConfig>, pub portfolio: Option<PortfolioConfig>, pub streaming: Option<StreamingConfig>, pub bypass_logging: bool, pub run_analysis: bool,
}
Configuration for BacktestEngine instances.

Fields

environment: Environment

The kernel environment context.

trader_id: TraderId

The trader ID for the node.

load_state: bool

If trading strategy state should be loaded from the database on start.

save_state: bool

If trading strategy state should be saved to the database on stop.

logging: LoggerConfig

The logging configuration for the kernel.

instance_id: Option<UUID4>

The unique instance identifier for the kernel.

timeout_connection: Duration

The timeout for all clients to connect and initialize.

timeout_reconciliation: Duration

The timeout for execution state to reconcile.

timeout_portfolio: Duration

The timeout for portfolio to initialize margins and unrealized pnls.

timeout_disconnection: Duration

The timeout for all engine clients to disconnect.

delay_post_stop: Duration

The delay after stopping the node to await residual events before final shutdown.

timeout_shutdown: Duration

The timeout to await pending tasks cancellation during shutdown.

cache: Option<CacheConfig>

The cache configuration.

msgbus: Option<MessageBusConfig>

The message bus configuration.

data_engine: Option<DataEngineConfig>

The data engine configuration.

risk_engine: Option<RiskEngineConfig>

The risk engine configuration.

exec_engine: Option<ExecutionEngineConfig>

The execution engine configuration.

portfolio: Option<PortfolioConfig>

The portfolio configuration.

streaming: Option<StreamingConfig>

The configuration for streaming to feather files.

bypass_logging: bool

If logging should be bypassed.

run_analysis: bool

If post backtest performance analysis should be run.

Implementations

Source

impl BacktestEngineConfig

pub fn new( environment: Environment, trader_id: TraderId, load_state: Option<bool>, save_state: Option<bool>, bypass_logging: Option<bool>, run_analysis: Option<bool>, timeout_connection: Option<u64>, timeout_reconciliation: Option<u64>, timeout_portfolio: Option<u64>, timeout_disconnection: Option<u64>, delay_post_stop: Option<u64>, timeout_shutdown: Option<u64>, logging: Option<LoggerConfig>, instance_id: Option<UUID4>, cache: Option<CacheConfig>, msgbus: Option<MessageBusConfig>, data_engine: Option<DataEngineConfig>, risk_engine: Option<RiskEngineConfig>, exec_engine: Option<ExecutionEngineConfig>, portfolio: Option<PortfolioConfig>, streaming: Option<StreamingConfig>, ) -> Self